Revision: 14459
Author:   [email protected]
Date:     Fri Apr 26 06:22:11 2013
Log:      Add assertion about module scopes to Scope::ContextChainLength.

[email protected]

Review URL: https://codereview.chromium.org/14513002
http://code.google.com/p/v8/source/detail?r=14459

Modified:
 /branches/bleeding_edge/src/scopes.cc

=======================================
--- /branches/bleeding_edge/src/scopes.cc       Fri Apr 26 04:55:22 2013
+++ /branches/bleeding_edge/src/scopes.cc       Fri Apr 26 06:22:11 2013
@@ -727,8 +727,9 @@
   for (Scope* s = this; s != scope; s = s->outer_scope_) {
     ASSERT(s != NULL);  // scope must be in the scope chain
     if (s->is_with_scope() || s->num_heap_slots() > 0) n++;
     // Catch scopes always have heap slots.
     ASSERT(!s->is_catch_scope() || s->num_heap_slots() > 0);
+    ASSERT(!s->is_module_scope() || s->num_heap_slots() > 0);
   }
   return n;
 }
@@ -727,8 +727,9 @@
     ASSERT(s != NULL);  // scope must be in the scope chain
     if (s->is_with_scope() || s->num_heap_slots() > 0) n++;
-    // Catch scopes always have heap slots.
+    // Catch and module scopes always have heap slots.
     ASSERT(!s->is_catch_scope() || s->num_heap_slots() > 0);

--
--
v8-dev mailing list
[email protected]
http://groups.google.com/group/v8-dev
--- You received this message because you are subscribed to the Google Groups "v8-dev" group.
To unsubscribe from this group and stop receiving emails from it, send an email 
to [email protected].
For more options, visit https://groups.google.com/groups/opt_out.


Reply via email to